@@ -511,6 +511,7 @@ pub fn op_name(op: u8) -> Result<&'static str, LangError> {
         ops::SUBC_ADDR_NUM_WORD => names::op::SUBC_ADDR_NUM_WORD,
         ops::SUBC_ADDR_ADDR_BYTE => names::op::SUBC_ADDR_ADDR_BYTE,
         ops::SUBC_ADDR_ADDR_WORD => names::op::SUBC_ADDR_ADDR_WORD,
+        ops::SLEEP => names::op::SLEEP,
         _ => return Err(InvalidInstructionCode(op)),
     };
     Ok(name)
@@ -730,6 +731,7 @@ pub fn op_desc(op: u8) -> Result<&'static str, LangError> {
         ops::SUBC_ADDR_NUM_WORD => names::full::SUBC_ADDR_NUM_WORD,
         ops::SUBC_ADDR_ADDR_BYTE => names::full::SUBC_ADDR_ADDR_BYTE,
         ops::SUBC_ADDR_ADDR_WORD => names::full::SUBC_ADDR_ADDR_WORD,
+        ops::SLEEP => names::full::SLEEP,
         _ => return Err(InvalidInstructionCode(op)),
     };
     Ok(name)
