@@ -1,3 +1,5 @@
+/// Command name + size, but no args
+/// e.g. `CPY.B`, `CALL`
 pub mod op {
     pub const NOP: &str = "NOP";
     pub const HALT: &str = "HALT";
@@ -223,8 +225,11 @@ pub mod op {
     pub const SUBC_ADDR_NUM_WORD: &str = "SUBC.W";
     pub const SUBC_ADDR_ADDR_BYTE: &str = "SUBC.B";
     pub const SUBC_ADDR_ADDR_WORD: &str = "SUBC.W";
+    pub const SLEEP: &str = "SLEEP";
 }
 
+/// Command name + size + args
+/// e.g. `CPY.B (R,R)`, `CALL (A)`
 pub mod full {
     pub const NOP: &str = "NOP";
     pub const HALT: &str = "HALT";
@@ -438,4 +443,5 @@ pub mod full {
     pub const SUBC_ADDR_NUM_WORD: &str = "SUBC.W (A,N)";
     pub const SUBC_ADDR_ADDR_BYTE: &str = "SUBC.B (A,A)";
     pub const SUBC_ADDR_ADDR_WORD: &str = "SUBC.W (A,A)";
+    pub const SLEEP: &str = "SLEEP";
 }
