@@ -1,12 +1,12 @@
-#[rustfmt::skip]
 /// Returns the number of bytes used for arguments for an op
+#[rustfmt::skip]
 pub fn get_byte_count(op: u8) -> usize {
     //rule is generally
     //each reg +1
     //each addr +2
     //each num is +1 if byte, +2 if word
     match op {
-        NOP | HALT | RET | RETI => 0,
+        NOP | HALT | RET | RETI | SLEEP => 0,
         INC_REG_BYTE | INC_REG_WORD | DEC_REG_BYTE | DEC_REG_WORD | CALL_REG | NOT_REG_BYTE
         | NOT_REG_WORD | ASL_REG_NUM_BYTE | ASL_REG_NUM_WORD | JMP_REG | JL_REG | JG_REG
         | JLE_REG | JGE_REG | JE_REG | JNE_REG | JRF_BYTE | JRB_BYTE => 1,
@@ -293,10 +293,12 @@ pub const SUBC_ADDR_NUM_BYTE: u8 = 0xF4;
 pub const SUBC_ADDR_NUM_WORD: u8 = 0xF5;
 pub const SUBC_ADDR_ADDR_BYTE: u8 = 0xF6;
 pub const SUBC_ADDR_ADDR_WORD: u8 = 0xF7;
-//unused 8 0xF8 - 0xFF
+//unused 8 0xF8 - 0xFE
+
+pub const SLEEP: u8 = 0xFF;
 
 #[rustfmt::skip]
-pub const ALL: [u8; 212] = [
+pub const ALL: [u8; 213] = [
     NOP, HALT,
     CALL_ADDR, CALL_REG, RET, RETI,
     CPY_REG_REG_BYTE, CPY_REG_REG_WORD, CPY_ADDR_REG_BYTE, CPY_ADDR_REG_WORD,
@@ -355,6 +357,7 @@ pub const ALL: [u8; 212] = [
     SUBC_REG_REG_BYTE, SUBC_REG_REG_WORD, SUBC_REG_NUM_BYTE, SUBC_REG_NUM_WORD,
     SUBC_REG_ADDR_BYTE, SUBC_REG_ADDR_WORD, SUBC_ADDR_REG_BYTE, SUBC_ADDR_REG_WORD,
     SUBC_ADDR_NUM_BYTE, SUBC_ADDR_NUM_WORD, SUBC_ADDR_ADDR_BYTE, SUBC_ADDR_ADDR_WORD,
+    SLEEP
 ];
 
 #[cfg(test)]
